@@ -6,7 +6,7 @@
 
 '''A simple Twitter client made with pyqt4'''
 
-__version__ = '0.1.7'
+__version__ = '0.1.9'
 
 #TODOS :
 #* Fix Identi.ca oauth bug
@@ -231,9 +231,7 @@ class KhweetAction(QDialog):
                 if int(self.settings.value('useAutoRotation')) == 2:
                     self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
             except:
-
                    # No pref yet default is true
-
                 self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
 
         _layout = QGridLayout(self)
@@ -286,6 +284,7 @@ class KhweeteurWin(QMainWindow):
             self.settings.setValue('twitter_access_token',1)
         else:
             self.settings.setValue('twitter_access_token',0)
+            
         if self.settings.value('identica_access_token') in ('True','1'):
             self.settings.setValue('identica_access_token',1)
         else:
@@ -367,6 +366,9 @@ class KhweeteurWin(QMainWindow):
                              )) * 60 * 1000)
 
         if not self.search_keyword:
+            if not (bool(self.settings.value('twitter_access_token')) or \
+                bool(self.settings.value('identica_access_token'))):
+                self.notifications.warn('Khweeteur aren\'t authorized to connect to any service. Please authorize one in preferences.')
             self.open_saved_search()
 
     def enterEvent(self, event):
@@ -478,15 +480,15 @@ class KhweeteurWin(QMainWindow):
 
         QTimer.singleShot(200, self.timedUnserialize)
 
-    @Slot
+    @pyqtSlot()
     def scrolltop(self):
         self.tweetsView.scrollToTop()
 
-    @Slot
+    @pyqtSlot()
     def scrollbottom(self):
         self.tweetsView.scrollToBottom()
 
-    @Slot
+    @pyqtSlot()
     def tweet_do_ask_action(self):
         user = None
         for index in self.tweetsView.selectedIndexes():
@@ -501,7 +503,7 @@ class KhweeteurWin(QMainWindow):
             self.tweetActionDialog.destroy_tweet.clicked.connect(self.destroy_tweet)
             self.tweetActionDialog.exec_()
 
-    @Slot
+    @pyqtSlot()
     def countCharsAndResize(self):
         local_self = self.tb_text
         self.tb_charCounter.setText(unicode(140
@@ -522,7 +524,7 @@ class KhweeteurWin(QMainWindow):
         local_self.setFixedHeight(min(370, s.height() + fr.height()
                                   - cr.height() - 1))
 
-    @Slot
+    @pyqtSlot()
     def reply(self):
         if self.tweetActionDialog != None:
             self.tweetActionDialog.accept()
@@ -535,9 +537,7 @@ class KhweeteurWin(QMainWindow):
             self.tb_text_replysource = self.tweetsModel.data(index,
                     role=ORIGINROLE)
 
-#            print self.tb_text_replysource, self.tb_text_replyid, self.tweetsModel._items[index.row()][3]
-
-    @Slot
+    @pyqtSlot()
     def open_url(self):
         import re
         self.tweetActionDialog.accept()
@@ -550,7 +550,7 @@ class KhweeteurWin(QMainWindow):
             except StandardError, e:
                 print e
 
-    @Slot
+    @pyqtSlot()
     def follow(self):
         self.tweetActionDialog.accept()
         if not self.nw.device_has_networking:
@@ -635,7 +635,7 @@ class KhweeteurWin(QMainWindow):
                                         ) % (user_screenname, str(e)))
                                 print e
 
-    @Slot
+    @pyqtSlot()
     def unfollow(self):
         self.tweetActionDialog.accept()
         if not self.nw.device_has_networking:
@@ -649,8 +649,6 @@ class KhweeteurWin(QMainWindow):
                         QMessageBox.Yes | QMessageBox.Close) \
                     == QMessageBox.Yes:
 
-                    # print 'DEBUG Follow:', user_screenname
-
                     if 'twitter' in self.tweetsModel.data(index,
                             role=ORIGINROLE):
                         try:
@@ -722,7 +720,7 @@ class KhweeteurWin(QMainWindow):
                                 self.notifications.warn(self.tr('Remove %s to friendship failed on Identi.ca : %s'
                                         ) % (user_screenname, str(e)))
                                 print e
-    @Slot
+    @pyqtSlot()
     def retweet(self):
         self.tweetActionDialog.accept()
         for index in self.tweetsView.selectedIndexes():
@@ -802,7 +800,7 @@ class KhweeteurWin(QMainWindow):
                                     ) + str(e))
                             print e
 
-    @Slot
+    @pyqtSlot()
     def destroy_tweet(self):
         self.tweetActionDialog.accept()
         for index in self.tweetsView.selectedIndexes():
@@ -884,19 +882,19 @@ class KhweeteurWin(QMainWindow):
                                      + str(e))
                             print e
 
-    @Slot
+    @pyqtSlot()
     def tweetSent(self):
         self.tb_text.setPlainText('')
         self.tb_text_replyid = 0
         self.tb_text_replytext = ''
         self.request_refresh()  # Feature Request : 201
 
-    @Slot
+    @pyqtSlot()
     def tweetSentFinished(self):
         self.tb_text.setEnabled(True)
         self.tb_tweet.setEnabled(True)
 
-    @Slot
+    @pyqtSlot()
     def tweet(self):
         try:
             if not self.nw.device_has_networking:
@@ -1134,8 +1132,7 @@ class KhweeteurWin(QMainWindow):
     def do_about(self):
         self.aboutWin = KhweeteurAbout(self)
 
-#    @Slot()
-
+#    @pyqtSlot()
     @pyqtSlot()
     def activated_by_dbus(self):
         self.tweetsModel.getNewAndReset()
