@@ -39,19 +39,19 @@ class KhweeteurRefreshWorker(QThread):
 
     def getCacheFolder(self):
         if not hasattr(self, 'keywords'):
-            folder_path = TIMELINE_PATH
+            self.folder_path = TIMELINE_PATH
         else:
-            folder_path = os.path.join(CACHE_PATH,
+            self.folder_path = os.path.join(CACHE_PATH,
                     os.path.normcase(unicode(self.keywords.replace('/',
                     '_'))).encode('UTF-8'))
 
-        if not os.path.isdir(folder_path):
+        if not os.path.isdir(self.folder_path):
             try:
-                os.makedirs(folder_path)
+                os.makedirs(self.folder_path)
             except IOError, e:
                 print 'getCacheFolder:', e
 
-        return folder_path
+        return self.folder_path
 
     def serialize(self, statuses):
 
@@ -105,7 +105,7 @@ class KhweeteurRefreshWorker(QThread):
                 status = pickle.load(fhandle)
                 fhandle.close()
                 return status.text
-            if os.path.exists(rpath_reply):
+            elif os.path.exists(rpath_reply):
                 fhandle = open(rpath_reply, 'rb')
                 status = pickle.load(fhandle)
                 fhandle.close()
@@ -122,6 +122,7 @@ class KhweeteurRefreshWorker(QThread):
             except:
                 import traceback
                 traceback.print_exc()
+                print 'Cannot write to reply path:',REPLY_PATH
 
         return None
 
@@ -150,7 +151,6 @@ class KhweeteurHomeTimelineWorker(KhweeteurRefreshWorker):
     def run(self):
 
         # Get Home TimeLine
-        print 'Refresh KhweeteurHomeTimelineWorker'
         try:
             statuses = \
                 self.api.GetFriendsTimeline(since_id=self.settings.value('last_id/'
@@ -164,8 +164,6 @@ class KhweeteurHomeTimelineWorker(KhweeteurRefreshWorker):
             statuses.sort()
             statuses.reverse()
             if len(statuses) > 0:
-                print 'Got new status', [status.id for status in
-                        statuses]
                 self.newStatuses.emit([status.id for status in
                         statuses])
                 self.settings.setValue('last_id/' + self.api.base_url
@@ -490,6 +488,7 @@ class KhweeteurWorker(QThread):
 
     def transmitNewStatuses(self, alist):
 #        self.emit(SIGNAL('newStatuses(list)'), list)
+        print 'transmitNewStatuses',len(alist)
         self.newStatuses.emit(alist)
 
     def refresh_unified(self, api):
@@ -602,4 +601,3 @@ class KhweeteurWorker(QThread):
                 print 'Bad status line : ', self.error.line
             else:
                 self.info.emit('A network error occur')
-        print 'DEBUG:Refresh ended'
